@@ -51,13 +51,16 @@ class SendToSentryTask(object):
         periodic_task.start()
 
     def handle_request(self, response):
-        logging.debug("Request handled in %.2f" % (time.time() - self.start_time))
-        self.application.last_requests.append(time.time() - self.start_time)
+        response_time = response.request_time
+        logging.debug("Request handled in %.2f" % response_time)
+        self.application.last_requests.append(response_time)
         self.application.last_requests = self.application.last_requests[
             max(0, len(self.application.last_requests) - self.application.config.MAX_REQUESTS_TO_AVERAGE):]
         self.application.average_request_time = self.mean(self.application.last_requests) * 1000
         self.application.percentile_request_time = self.calculate_percentile() * 1000
 
+        self.application.items_to_process.task_done()
+
         if response.error:
             logging.error("Error: %s" % response.error)
         else:
@@ -90,7 +93,6 @@ class SendToSentryTask(object):
             self.last_sent = time.time()
             http_client = AsyncHTTPClient(io_loop=self.main_loop)
             http_client.fetch(request, self.handle_request)
-            self.application.items_to_process.task_done()
         except Queue.Empty:
             pass
 
